@@ -25,7 +25,7 @@ def test_html_attribute_escape_with_recipe():
     serializer = Serializer('tiddlywebwiki.serialization', environ)
     serializer.object = tiddler
     string = serializer.to_string()
-
+    
     assert r'''title="escape &quot;double&quot; quotes &amp; &amp;amp; in &lt;tiddler&gt; field values"''' in string
     assert r'''server.title="escape &quot;double&quot; quotes &amp; &amp;amp; in &lt;tiddler&gt; field values"''' in string
     assert r'''bag="foo &quot;bar&quot; baz"''' in string
@@ -35,8 +35,7 @@ def test_html_attribute_escape_with_recipe():
     assert r'''creator="Chris &quot;sensei&quot; Dent"''' in string
     assert r'''tags="foo [[xxx &quot;yyy&quot; zzz]]"''' in string
     assert r'''custom="lorem 'ipsum' dolor &quot;sit&quot; amet"''' in string
-    assert r'''you may still <a href="http://0.0.0.0:8080/recipes/baz%20%22bar%22%20foo/tiddlers">browse''' in string
-
+    assert r'''you may still <a href="http://our_test_domain:8001/recipes/baz%20%22bar%22%20foo/tiddlers">browse''' in string
 
 def test_html_attribute_escape_with_bag():
     tiddler = Tiddler('escape "double" quotes in tiddler field values')
@@ -57,7 +56,7 @@ def test_html_attribute_escape_with_bag():
     assert r'''creator="Chris &quot;sensei&quot; Dent"''' in string
     assert r'''tags="foo [[xxx &quot;yyy&quot; zzz]]"''' in string
     assert r'''custom="lorem 'ipsum' dolor &quot;sit&quot; amet"''' in string
-    assert r'''you may still <a href="http://0.0.0.0:8080/bags/foo%20%22bar%22%20baz/tiddlers">browse''' in string
+    assert r'''you may still <a href="http://our_test_domain:8001/bags/foo%20%22bar%22%20baz/tiddlers">browse''' in string
 
 
 def test_content_type():
